@@ -284,3 +284,22 @@ class LoadMaster(HttpClient):
             return ApiXmlHelper.parse_to_dict(response)
         else:
             raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
+
+    def restore_backup(self, backup_type, file):
+        # 1 LoadMaster Base Configuration
+        # 2 Virtual Service Configuration
+        # 3 GEO Configuration
+        if backup_type not in [1, 2, 3]:
+            backup_type = 2
+        response = self._post('/restore?type={}'.format(backup_type), file)
+        if ApiXmlHelper.is_successful(response):
+            return ApiXmlHelper.parse_to_dict(response)
+        else:
+            raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
+
+    def backup(self):
+        response = self._get('/backup')
+        if ApiXmlHelper.is_successful(response):
+            return ApiXmlHelper.parse_to_dict(response)
+        else:
+            raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
